@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "lisp-chat" "0.7.0"
+(define-package "lisp-chat" "20260302.7"
   "Emacs client for Lisp Chat."
   '((emacs     "26.1")
     (websocket "1.12"))
   :url "https://github.com/ryukinix/lisp-chat"
-  :commit "3e80158a6d3e6c3447c3ab2fe09a182736bf0ad0"
-  :revdesc "3e80158a6d3e"
+  :commit "43bab123c861ed0dd11d076af9a61d641ed259f5"
+  :revdesc "43bab123c861"
   :keywords '("comm" "chat" "lisp"))
